@@ -28,5 +28,7 @@ module Astute
   class MClientError < AstuteError; end
   # MClient timeout error
   class MClientTimeout < Timeout::Error; end
+  # Task validation error
+  class TaskValidationError < AstuteError; end
 
 end
