@@ -48,7 +48,7 @@ describe Astute::DeploymentEngine do
     end
 
     it 'should be avaliable as superclass' do
-      expect { Engine.new(ctx) }.to be_true
+      expect(Engine.new(ctx)).to be_truthy
     end
   end
 
@@ -416,14 +416,12 @@ describe Astute::DeploymentEngine do
           'nodes' => [
             {'uid' => '1', 'role' => 'compute'},
             {'uid' => '2', 'role' => 'primary-controller'},
-            {'uid' => '4', 'role' => 'compute'}
           ]
         },
         {'uid' => "2", 'priority' => 10, 'role' => 'primary-controller',
           'nodes' => [
             {'uid' => '1', 'role' => 'compute'},
             {'uid' => '2', 'role' => 'primary-controller'},
-            {'uid' => '4', 'role' => 'compute'}
           ]
         }
       ]
@@ -443,6 +441,12 @@ describe Astute::DeploymentEngine do
           'error_type' => 'provision',
           'role' => 'hook',
           'error_msg' => 'Node is not ready for deployment: mcollective has not answered'
+        },{
+          'uid' => '4',
+          'status' => 'error',
+          'error_type' => 'provision',
+          'role' => 'hook',
+          'error_msg' => 'Node is not ready for deployment: mcollective has not answered'
         }],
         'error' => 'Node is not ready for deployment'
       )
@@ -488,14 +492,12 @@ describe Astute::DeploymentEngine do
           'nodes' => [
             {'uid' => '1', 'role' => 'compute'},
             {'uid' => '2', 'role' => 'primary-controller'},
-            {'uid' => '4', 'role' => 'compute'}
           ]
         },
         {'uid' => "2", 'priority' => 10, 'role' => 'primary-controller',
           'nodes' => [
             {'uid' => '1', 'role' => 'compute'},
             {'uid' => '2', 'role' => 'primary-controller'},
-            {'uid' => '4', 'role' => 'compute'}
           ]
         }
       ]
@@ -515,6 +517,12 @@ describe Astute::DeploymentEngine do
           'error_type' => 'provision',
           'role' => 'hook',
           'error_msg' => 'Node is not ready for deployment: mcollective has not answered'
+        }, {
+          'uid' => '4',
+          'status' => 'error',
+          'error_type' => 'provision',
+          'role' => 'hook',
+          'error_msg' => 'Node is not ready for deployment: mcollective has not answered'
         }],
         'error' => 'Node is not ready for deployment'
       )
@@ -546,7 +554,7 @@ describe Astute::DeploymentEngine do
             {'uid' => '1', 'role' => 'compute'},
             {'uid' => '2', 'role' => 'primary-controller'},
             {'uid' => '4', 'role' => 'compute'}
-          ]}
+        ]}
       ]
 
       res1 = {:data => {:node_type => "target\n"},
@@ -565,6 +573,12 @@ describe Astute::DeploymentEngine do
           'error_type' => 'provision',
           'role' => 'hook',
           'error_msg' => 'Node is not ready for deployment: mcollective has not answered'
+        },{
+          'uid' => '4',
+          'status' => 'error',
+          'error_type' => 'provision',
+          'role' => 'hook',
+          'error_msg' => 'Node is not ready for deployment: mcollective has not answered'
         }],
         'error' => 'Node is not ready for deployment'
       )
