@@ -84,7 +84,8 @@ describe Astute::NailgunHooks do
         "puppet_manifest" =>  "cinder_glusterfs.pp",
         "puppet_modules" =>  "modules",
         "cwd" => "/etc/fuel/plugins/plugin_name-1.0",
-        "timeout" =>  42
+        "timeout" =>  42,
+        "retries" => 21
       }
     }
   end
@@ -120,24 +121,44 @@ describe Astute::NailgunHooks do
   end
 
   let(:upload_files_hook) do
-      {
-        "priority" =>  100,
-        "type" =>  "upload_files",
-        "fail_on_error" => false,
-        "diagnostic_name" => "copy-example-1.0",
-        "uids" =>  ['1'],
-        "parameters" =>  {
-          "nodes" =>[
-            "uid" => '1',
-            "files" => [{
-              "dst" => "/etc/fuel/nova.key",
-              "data" => "",
-              "permissions" => "0600",
-              "dir_permissions" => "0700"}],
-          ]
+    {
+      "priority" =>  100,
+      "type" =>  "upload_files",
+      "fail_on_error" => false,
+      "diagnostic_name" => "copy-example-1.0",
+      "uids" =>  ['1'],
+      "parameters" =>  {
+        "nodes" =>[
+          "uid" => '1',
+          "files" => [{
+            "dst" => "/etc/fuel/nova.key",
+            "data" => "",
+            "permissions" => "0600",
+            "dir_permissions" => "0700"}],
+        ]
+      }
+    }
+  end
+
+  let (:cobbler_sync_hook) do
+    {
+      "priority" => 800,
+      "type" => "cobbler_sync",
+      "fail_on_error" => false,
+      "diagnostic_name" => "copy-example-1.0",
+      "uids" => ['master'],
+      "parameters" => {
+        "provisioning_info" => {
+          "engine" => {
+            "url" => "http://10.20.0.2:80/cobbler_api",
+            "username" => "cobbler",
+            "password" => "cobblerpassword",
+            "master_ip" => "10.20.0.2"
+          }
         }
       }
-    end
+    }
+  end
 
   let(:hooks_data) do
     [
@@ -374,7 +395,7 @@ describe Astute::NailgunHooks do
     it 'should upload file' do
       File.stubs(:file?).returns(true)
       File.stubs(:readable?).returns(true)
-      File.stubs(:read).returns("")
+      File.stubs(:binread).returns("")
       hooks = Astute::NailgunHooks.new([copy_files_hook], ctx)
 
       hooks.expects(:upload_file).once.with(
@@ -393,7 +414,7 @@ describe Astute::NailgunHooks do
       Astute.config.max_nodes_per_call = 1
       File.stubs(:file?).returns(true)
       File.stubs(:readable?).returns(true)
-      File.stubs(:read).returns("")
+      File.stubs(:binread).returns("")
       hooks = Astute::NailgunHooks.new([copy_files_hook], ctx)
 
       hooks.expects(:upload_file).once.with(
@@ -424,7 +445,7 @@ describe Astute::NailgunHooks do
       it 'mcagent success' do
         File.stubs(:file?).returns(true)
         File.stubs(:readable?).returns(true)
-        File.stubs(:read).returns("")
+        File.stubs(:binread).returns("")
         hooks = Astute::NailgunHooks.new([copy_files_hook], ctx)
         hooks.expects(:upload_file).returns(true).once
 
@@ -434,7 +455,7 @@ describe Astute::NailgunHooks do
       it 'mcagent fail' do
         File.stubs(:file?).returns(true)
         File.stubs(:readable?).returns(true)
-        File.stubs(:read).returns("")
+        File.stubs(:binread).returns("")
 
         hooks = Astute::NailgunHooks.new([copy_files_hook], ctx)
         hooks.expects(:upload_file).returns(false).once
@@ -569,21 +590,21 @@ describe Astute::NailgunHooks do
 
       it 'if exit code eql 0 -> do not raise error' do
         hooks = Astute::NailgunHooks.new([shell_hook], ctx)
-        hooks.expects(:run_shell_command).returns(true).once
+        hooks.expects(:run_shell_command).returns(nil).once
 
         expect {hooks.process}.to_not raise_error
       end
 
       it 'if exit code not eql 0 -> raise error' do
         hooks = Astute::NailgunHooks.new([shell_hook], ctx)
-        hooks.expects(:run_shell_command).returns(false).once
+        hooks.expects(:run_shell_command).returns("err").once
 
         expect {hooks.process}.to raise_error(Astute::DeploymentEngineError, /Failed to execute hook/)
       end
 
       it 'if exit code not presence -> raise error' do
         hooks = Astute::NailgunHooks.new([shell_hook], ctx)
-        hooks.expects(:run_shell_command).returns(false).once
+        hooks.expects(:run_shell_command).returns("err").once
 
         expect {hooks.process}.to raise_error(Astute::DeploymentEngineError, /Failed to execute hook/)
       end
@@ -661,7 +682,9 @@ describe Astute::NailgunHooks do
           .then.raises(Astute::MClientError)
           .then.returns([mc_result('3', true)])
 
-        expect {hooks.process}.to_not raise_error(Astute::DeploymentEngineError)
+        expect {
+          hooks.process
+        }.not_to raise_error(Astute::DeploymentEngineError)
       end
 
       it 'should fail if it still raise error after retries' do
@@ -852,21 +875,21 @@ describe Astute::NailgunHooks do
 
       it 'if exit code eql 0 -> do not raise error' do
         hooks = Astute::NailgunHooks.new([sync_hook], ctx)
-        hooks.expects(:run_shell_command).returns(true).once
+        hooks.expects(:run_shell_command).returns(nil).once
 
         expect {hooks.process}.to_not raise_error
       end
 
       it 'if exit code not eql 0 -> raise error' do
         hooks = Astute::NailgunHooks.new([sync_hook], ctx)
-        hooks.expects(:run_shell_command).returns(false).once
+        hooks.expects(:run_shell_command).returns("err").once
 
         expect {hooks.process}.to raise_error(Astute::DeploymentEngineError, /Failed to execute hook/)
       end
 
       it 'if exit code not presence -> raise error' do
         hooks = Astute::NailgunHooks.new([sync_hook], ctx)
-        hooks.expects(:run_shell_command).returns(false).once
+        hooks.expects(:run_shell_command).returns("err").once
 
         expect {hooks.process}.to raise_error(Astute::DeploymentEngineError, /Failed to execute hook/)
       end
@@ -911,7 +934,7 @@ describe Astute::NailgunHooks do
           {'uid' => '1', 'role' => 'hook'},
           {'uid' => '3', 'role' => 'hook'}
         ],
-        retries=2,
+        retries=puppet_hook['parameters']['retries'],
         puppet_hook['parameters']['puppet_manifest'],
         puppet_hook['parameters']['puppet_modules'],
         puppet_hook['parameters']['cwd']
@@ -929,7 +952,8 @@ describe Astute::NailgunHooks do
         puppet_hook['parameters']['puppet_manifest'],
         puppet_hook['parameters']['puppet_modules'],
         puppet_hook['parameters']['cwd'],
-        puppet_hook['parameters']['timeout']
+        puppet_hook['parameters']['timeout'],
+        puppet_hook['parameters']['retries']
       ).returns(true)
       Astute::Context.any_instance.stubs(:status).returns({'1' => 'success', '3' => 'success'})
 
@@ -945,7 +969,25 @@ describe Astute::NailgunHooks do
         puppet_hook['parameters']['puppet_manifest'],
         puppet_hook['parameters']['puppet_modules'],
         puppet_hook['parameters']['cwd'],
-        300
+        300,
+        puppet_hook['parameters']['retries']
+      ).returns(true)
+      Astute::Context.any_instance.stubs(:status).returns({'1' => 'success', '3' => 'success'})
+
+      hooks.process
+    end
+
+    it 'should use default retries if it does not set' do
+      puppet_hook['parameters'].delete('retries')
+      hooks = Astute::NailgunHooks.new([puppet_hook], ctx)
+      hooks.expects(:run_puppet).once.with(
+        ctx,
+        ['1','3'],
+        puppet_hook['parameters']['puppet_manifest'],
+        puppet_hook['parameters']['puppet_modules'],
+        puppet_hook['parameters']['cwd'],
+        puppet_hook['parameters']['timeout'],
+        Astute.config.puppet_retries,
       ).returns(true)
       Astute::Context.any_instance.stubs(:status).returns({'1' => 'success', '3' => 'success'})
 
@@ -962,7 +1004,8 @@ describe Astute::NailgunHooks do
         puppet_hook['parameters']['puppet_manifest'],
         puppet_hook['parameters']['puppet_modules'],
         puppet_hook['parameters']['cwd'],
-        puppet_hook['parameters']['timeout']
+        puppet_hook['parameters']['timeout'],
+        puppet_hook['parameters']['retries']
       ).returns(true)
 
       hooks.expects(:run_puppet).once.with(
@@ -971,7 +1014,8 @@ describe Astute::NailgunHooks do
         puppet_hook['parameters']['puppet_manifest'],
         puppet_hook['parameters']['puppet_modules'],
         puppet_hook['parameters']['cwd'],
-        puppet_hook['parameters']['timeout']
+        puppet_hook['parameters']['timeout'],
+        puppet_hook['parameters']['retries']
       ).returns(true)
 
       Astute::Context.any_instance.stubs(:status).returns({'1' => 'success', '3' => 'success'})
@@ -1301,4 +1345,22 @@ describe Astute::NailgunHooks do
 
   end #reboot_hook
 
+  context '#cobbler_sync_hook' do
+
+    it 'should validate presence of provisioning_info' do
+      cobbler_sync_hook['parameters']['provisioning_info'] = {}
+      hooks = Astute::NailgunHooks.new([cobbler_sync_hook], ctx)
+
+      expect {hooks.process}.to raise_error(StandardError, /Missing a required parameter/)
+    end
+
+    it 'should call Astute::CobblerManager sync method ' do
+      hooks = Astute::NailgunHooks.new([cobbler_sync_hook], ctx)
+      Astute::CobblerManager.any_instance.expects(:sync).once
+
+      hooks.process
+    end
+
+  end #cobbler_sync_hook
+
 end # 'describe'
