@@ -241,24 +241,23 @@ describe Astute::Provisioner do
         Astute::Provision::Cobbler.any_instance do
           expects(:power_reboot).with('controller-1')
         end
-        Astute::CobblerManager.any_instance.stubs(:check_reboot_nodes).returns([])
         Astute::CobblerManager.any_instance.stubs(:netboot_nodes)
         Astute::CobblerManager.any_instance.stubs(:edit_nodes)
         @provisioner.stubs(:change_nodes_type)
         @provisioner.stubs(:image_provision).returns([])
 
+        Astute::CobblerManager.any_instance.expects(:check_reboot_nodes).never
+        @provisioner.expects(:soft_reboot).returns()
+
         @provisioner.provision_piece(@reporter, data['task_uuid'], data['engine'], data['nodes'], 'image')
       end
 
       it "does not reboot nodes which failed during provisioning" do
-        Astute::Provision::Cobbler.any_instance do
-          expects(:power_reboot).never
-        end
-        Astute::CobblerManager.any_instance.stubs(:check_reboot_nodes).returns([])
         Astute::CobblerManager.any_instance.stubs(:netboot_nodes)
         Astute::CobblerManager.any_instance.stubs(:edit_nodes)
         @provisioner.stubs(:change_nodes_type)
         @provisioner.stubs(:image_provision).returns(['1'])
+        @provisioner.stubs(:soft_reboot).returns()
 
         expect(@provisioner.provision_piece(@reporter, data['task_uuid'], data['engine'], data['nodes'], 'image')).to eql(['1'])
       end
@@ -270,11 +269,11 @@ describe Astute::Provisioner do
             {'profile' => Astute.config.bootstrap_profile}
           )
         end
-        Astute::CobblerManager.any_instance.stubs(:check_reboot_nodes).returns([])
         Astute::CobblerManager.any_instance.stubs(:netboot_nodes)
         Astute::CobblerManager.any_instance.stubs(:edit_nodes)
         @provisioner.stubs(:change_nodes_type)
         @provisioner.stubs(:image_provision).returns([])
+        @provisioner.stubs(:soft_reboot).returns()
 
         @provisioner.provision_piece(@reporter, data['task_uuid'], data['engine'], data['nodes'], 'image')
       end
@@ -283,10 +282,10 @@ describe Astute::Provisioner do
         Astute::CobblerManager.any_instance do
           expects(:netboot_nodes).with([], false)
         end
-        Astute::CobblerManager.any_instance.stubs(:check_reboot_nodes).returns([])
         Astute::CobblerManager.any_instance.stubs(:edit_nodes)
         Astute::CobblerManager.any_instance.stubs(:netboot_nodes)
         @provisioner.stubs(:change_nodes_type)
+        @provisioner.stubs(:soft_reboot).returns()
         @provisioner.stubs(:image_provision).returns([1])
 
         @provisioner.provision_piece(@reporter, data['task_uuid'], data['engine'], data['nodes'], 'image')
@@ -302,6 +301,7 @@ describe Astute::Provisioner do
             .returns([Time.now.to_f, 'controller-1', 'complete'])
           Astute::CobblerManager.any_instance.stubs(:netboot_nodes)
           @provisioner.stubs(:change_nodes_type)
+          @provisioner.stubs(:soft_reboot).returns()
           @provisioner.stubs(:image_provision).returns([])
 
           @provisioner.provision_piece(@reporter, data['task_uuid'], data['engine'], data['nodes'], 'image')
@@ -507,14 +507,20 @@ describe Astute::Provisioner do
       end.to raise_error(Astute::AstuteError)
     end
 
-    it "should try to unlock nodes discovery" do
-      @provisioner.expects(:unlock_nodes_discovery)
+    it "should try to unlock discovery for all nodes if provision fail unexpectedly" do
+      @provisioner.expects(:unlock_nodes_discovery).with(
+        @reporter,
+        data['task_uuid'],
+        data['nodes'].map { |n| n['uid'] },
+        data['nodes']
+      )
+      @provisioner.stubs(:prepare_nodes).returns([])
+      @provisioner.stubs(:provision_and_watch_progress).raises(
+        StandardError,
+        "MESSAGE"
+      )
+      Astute::Rsyslogd.stubs(:send_sighup)
       begin
-        @provisioner.stubs(:remove_nodes).returns([])
-        @provisioner.stubs(:prepare_nodes).returns([])
-        Astute::CobblerManager.any_instance.stubs(:add_nodes).returns([])
-        @provisioner.stubs(:node_type).returns([])
-        @provisioner.stubs(:provision_piece).returns([{'uid' => '1'}])
         @provisioner.provision(@reporter, data['task_uuid'], data, 'image')
       rescue
       end
@@ -841,7 +847,7 @@ describe Astute::Provisioner do
                         'fault_tolerance' => []}
 
       @reporter.expects(:report).with(success_msg).once
-      @provisioner.provision(@reporter, data['task_uuid'], provision_info,  'image')
+      @provisioner.provision(@reporter, data['task_uuid'], provision_info, 'image')
 
     end
   end
@@ -1066,9 +1072,9 @@ describe Astute::Provisioner do
 
     it 'return failed nodes if image provision return failed uid' do
       Astute::CobblerManager.any_instance.stubs(:netboot_nodes)
-      Astute::CobblerManager.any_instance.stubs(:reboot_nodes)
       Astute::CobblerManager.any_instance.stubs(:check_reboot_nodes).returns(['node1'])
       @provisioner.stubs(:change_nodes_type)
+      @provisioner.stubs(:control_reboot_using_ssh)
       Astute::ImageProvision.stubs(:provision).returns(['1'])
       result = @provisioner.provision_piece(@reporter, 'task_uuid', engine_attrs, nodes, 'image')
       result.should eql(['1'])
